==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/ResourceProviderManifestPropertiesTemplateDeploymentOptionsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.ResourceProviderManifestPropertiesTemplateDeploymentOptionsArgs.builder
import com.pulumi.azurenative.providerhub.kotlin.enums.PreflightOption
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property preflightOptions
 * @property preflightSupported
 */
public data class ResourceProviderManifestPropertiesTemplateDeploymentOptionsArgs(
    public val preflightOptions: Output<List<Either<String, PreflightOption>>>? = null,
    public val preflightSupported: Output<Boolean>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.ResourceProviderManifestPropertiesTemplateDeploymentOptionsArgs> {
    override fun toJava():
        com.pulumi.azurenative.providerhub.inputs.ResourceProviderManifestPropertiesTemplateDeploymentOptionsArgs =
        com.pulumi.azurenative.providerhub.inputs.ResourceProviderManifestPropertiesTemplateDeploymentOptionsArgs.builder()
            .preflightOptions(
                preflightOptions?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform({ args0 -> args0 }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                    })
                }),
            )
            .preflightSupported(preflightSupported?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ResourceProviderManifestPropertiesTemplateDeploymentOptionsArgs].
 */
@PulumiTagMarker
public class ResourceProviderManifestPropertiesTemplateDeploymentOptionsArgsBuilder internal
constructor() {
    private var preflightOptions: Output<List<Either<String, PreflightOption>>>? = null

    private var preflightSupported: Output<Boolean>? = null

    /**
     * @param value
     */
    @JvmName("vewubpietiptiach")
    public suspend fun preflightOptions(`value`: Output<List<Either<String, PreflightOption>>>) {
        this.preflightOptions = value
    }

    @JvmName("jmtbxtnudgawnoqp")
    public suspend fun preflightOptions(vararg values: Output<Either<String, PreflightOption>>) {
        this.preflightOptions = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("knyuilphdxekjsnl")
    public suspend fun preflightOptions(values: List<Output<Either<String, PreflightOption>>>) {
        this.preflightOptions = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("cxgwfqbvndbmgfbd")
    public suspend fun preflightSupported(`value`: Output<Boolean>) {
        this.preflightSupported = value
    }

    /**
     * @param value
     */
    @JvmName("ubehacdtbvyrvcvj")
    public suspend fun preflightOptions(`value`: List<Either<String, PreflightOption>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.preflightOptions = mapped
    }

    /**
     * @param values
     */
    @JvmName("wndhxocfwiqnfnix")
    public suspend fun preflightOptions(vararg values: Either<String, PreflightOption>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.preflightOptions = mapped
    }

    /**
     * @param value
     */
    @JvmName("nqxhyobqsohnkcwg")
    public suspend fun preflightSupported(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.preflightSupported = mapped
    }

    internal fun build(): ResourceProviderManifestPropertiesTemplateDeploymentOptionsArgs =
        ResourceProviderManifestPropertiesTemplateDeploymentOptionsArgs(
            preflightOptions = preflightOptions,
            preflightSupported = preflightSupported,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/ResourceProviderManifestPropertiesTemplateDeploymentOptionsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.ResourceProviderManifestPropertiesTemplateDeploymentOptionsArgs.builder
import com.pulumi.azurenative.providerhub.kotlin.enums.PreflightOption
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property preflightOptions
 * @property preflightSupported
 */
public data class ResourceProviderManifestPropertiesTemplateDeploymentOptionsArgs(
    public val preflightOptions: Output<List<Either<String, PreflightOption>>>? = null,
    public val preflightSupported: Output<Boolean>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.ResourceProviderManifestPropertiesTemplateDeploymentOptionsArgs> {
    override fun toJava():
        com.pulumi.azurenative.providerhub.inputs.ResourceProviderManifestPropertiesTemplateDeploymentOptionsArgs =
        com.pulumi.azurenative.providerhub.inputs.ResourceProviderManifestPropertiesTemplateDeploymentOptionsArgs.builder()
            .preflightOptions(
                preflightOptions?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform({ args0 -> args0 }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                    })
                }),
            )
            .preflightSupported(preflightSupported?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ResourceProviderManifestPropertiesTemplateDeploymentOptionsArgs].
 */
@PulumiTagMarker
public class ResourceProviderManifestPropertiesTemplateDeploymentOptionsArgsBuilder internal
constructor() {
    private var preflightOptions: Output<List<Either<String, PreflightOption>>>? = null

    private var preflightSupported: Output<Boolean>? = null

    /**
     * @param value
     */
    @JvmName("qlqqdixiwdasynym")
    public suspend fun preflightOptions(`value`: Output<List<Either<String, PreflightOption>>>) {
        this.preflightOptions = value
    }

    @JvmName("cfgcbnkwkdriqrfg")
    public suspend fun preflightOptions(vararg values: Output<Either<String, PreflightOption>>) {
        this.preflightOptions = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("wxrpxmuuvrmsnaau")
    public suspend fun preflightOptions(values: List<Output<Either<String, PreflightOption>>>) {
        this.preflightOptions = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("kcqhdylprokccaqn")
    public suspend fun preflightSupported(`value`: Output<Boolean>) {
        this.preflightSupported = value
    }

    /**
     * @param value
     */
    @JvmName("nfpvojjhdklluueh")
    public suspend fun preflightOptions(`value`: List<Either<String, PreflightOption>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.preflightOptions = mapped
    }

    /**
     * @param values
     */
    @JvmName("ulskskxihsmgjwwa")
    public suspend fun preflightOptions(vararg values: Either<String, PreflightOption>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.preflightOptions = mapped
    }

    /**
     * @param value
     */
    @JvmName("xxqwntwstusgbfjj")
    public suspend fun preflightSupported(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.preflightSupported = mapped
    }

    internal fun build(): ResourceProviderManifestPropertiesTemplateDeploymentOptionsArgs =
        ResourceProviderManifestPropertiesTemplateDeploymentOptionsArgs(
            preflightOptions = preflightOptions,
            preflightSupported = preflightSupported,
        )
}
